//Chocolate.cs

datablock AudioProfile(ChocolateEatenSound)
{
   filename    = "./chocolatebite.wav";
   description = AudioClose3d;
   preload = true;
};

datablock ParticleData(LoveChocoParticle)
{
   dragCoefficient      = 5.0;
   gravityCoefficient   = -0.2;
   inheritedVelFactor   = 0.0;
   constantAcceleration = 0.0;
   lifetimeMS           = 1000;
   lifetimeVarianceMS   = 500;
   useInvAlpha          = false;
   textureName          = "./LoveChoco";
   colors[0]     = "1.0 1.0 1.0 1";
   colors[1]     = "1.0 1.0 1.0 1";
   colors[2]     = "0.0 0.0 0.0 0";
   sizes[0]      = 0.4;
   sizes[1]      = 0.6;
   sizes[2]      = 0.4;
   times[0]      = 0.0;
   times[1]      = 0.2;
   times[2]      = 1.0;
};

datablock ParticleEmitterData(LoveChocoEmitter)
{
   ejectionPeriodMS = 35;
   periodVarianceMS = 0;
   ejectionVelocity = 0.5;
   ejectionOffset   = 1.0;
   velocityVariance = 0.49;
   thetaMin         = 0;
   thetaMax         = 120;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance = false;
   particles = "LoveChocoParticle";

   uiName = "Emote - Love Choco";
};

datablock ShapeBaseImageData(LoveChocoImage)
{
	shapeFile = "base/data/shapes/empty.dts";
	emap = false;

	mountPoint = $HeadSlot;

	stateName[0]					= "Ready";
	stateTransitionOnTimeout[0]		= "FireA";
	stateTimeoutValue[0]			= 0.01;

	stateName[1]					= "FireA";
	stateTransitionOnTimeout[1]		= "Done";
	stateWaitForTimeout[1]			= True;
	stateTimeoutValue[1]			= 0.350;
	stateSound[1]					= ChocolateEatenSound;
	stateEmitter[1]					= LoveChocoEmitter;
	stateEmitterTime[1]				= 0.350;

	stateName[2]					= "Done";
	stateScript[2]					= "onDone";
};
function LoveChocoImage::onDone(%this,%obj,%slot)
{
	%obj.unMountImage(%slot);
}

datablock ItemData(ChocolateItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "base/data/shapes/brickweapon.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Chocolate Bar";
	iconName = "./Chocolate";
	doColorShift = false;

	 // Dynamic properties defined by the scripts
	image = ChocolateImage;
	canDrop = true;
};

datablock ShapeBaseImageData(ChocolateImage)
{
   // Basic Item properties
   shapeFile = "base/data/shapes/brickweapon.dts";
   emap = true;

   // Specify mount point & offset for 3rd person, and eye offset
   // for first person rendering.
   mountPoint = 0;
   offset = "0 0 0";
   eyeOffset = 0; //"0.7 1.2 -0.5";
   rotation = eulerToMatrix( "0 0 0" );

   className = "WeaponImage";
   item = ChocolateItem;

   //raise your arm up or not
   armReady = false;

   doColorShift = true;
   colorShiftColor = "0.400 0.196 0 1.000";

   // Initial start up state
	stateName[0]                     = "Ready";
	stateTransitionOnTriggerDown[0]  = "Fire";
	stateAllowImageChange[0]         = true;

	stateName[1]                     = "Fire";
	stateTransitionOnTimeout[1]      = "Ready";
	stateAllowImageChange[1]         = true;
      stateScript[1]                   = "onFire";
	stateTimeoutValue[1]		   = 1;
};

function ChocolateImage::onFire(%this,%obj,%slot)
{
	%currSlot = %obj.currTool;
	%obj.setDamageLevel(0);
	%obj.emote(LoveChocoImage,1);
	%obj.tool[%currSlot] = 0;
	%obj.weaponCount--;
	messageClient(%obj.client,'MsgItemPickup','',%currSlot,0);
	serverCmdUnUseTool(%obj.client);
}

package ChocolatePackage
{
	function Armor::onCollision(%this, %obj, %col, %a, %b, %c, %d, %e, %f)
	{
		if(%col.dataBlock $= "ChocolateItem" && %obj.getDamagePercent() < 100 && %col.canPickup)
		{
			if(!isObject(%col.spawnbrick) && !%col.nowPickup)	
			{
				if(isObject(%obj.client.minigame))
				{
					if(%obj.client.minigame $= %col.minigame)
					{
						if(%obj.getDamageLevel() >= 1)
						{
							%obj.setDamageLevel(0);
							%obj.emote(LoveChocoImage);
							%col.delete();
						}
						else
						{
							%col.nowPickup = 1;
						}
						return;
					}
				}
			}

			for(%i=0;%i<%this.maxTools;%i++)
			{
				%item = %obj.tool[%i];
				if(%item $= 0 || %item $= "")
				{
					%freeSlot = 1;
					break;
				}
			}

			if(%freeSlot)
			{
				%obj.pickup(%col);
				return;
			}
		}
		Parent::onCollision(%this, %obj, %col, %a, %b, %c, %d, %e, %f);
	}
};
activatePackage(ChocolatePackage);

datablock DecalData(ChocolateIcon)
{
   textureName = "Add-Ons/Item_Chocolate/Chocolate";
};